==> open-xchange-core_7.6.3.orig.tar.bz2: open-xchange-core-7.6.3/com.openexchange.jslob/src/com/openexchange/jslob/internal/JSlobStorageRegistryImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.jslob.internal;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import com.openexchange.exception.OXException;
import com.openexchange.jslob.storage.JSlobStorage;
import com.openexchange.jslob.storage.registry.JSlobStorageRegistry;

/**
 * {@link JSlobStorageRegistryImpl}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class JSlobStorageRegistryImpl implements JSlobStorageRegistry {

    private static final JSlobStorageRegistryImpl INSTANCE = new JSlobStorageRegistryImpl();

    /**
     * Gets the instance.
     *
     * @return The instance
     */
    public static JSlobStorageRegistryImpl getInstance() {
        return INSTANCE;
    }

    private final ConcurrentMap<String, JSlobStorage> registry;

    /**
     * Initializes a new {@link JSlobStorageRegistryImpl}.
     */
    private JSlobStorageRegistryImpl() {
        super();
        registry = new ConcurrentHashMap<String, JSlobStorage>(2);
    }

    @Override
    public JSlobStorage getJSlobStorage(final String storageId) throws OXException {
        return registry.get(storageId);
    }

    @Override
    public Collection<JSlobStorage> getJSlobStorages() throws OXException {
        final List<JSlobStorage> list = new ArrayList<JSlobStorage>(8);
        list.addAll(registry.values());
        return list;
    }

    @Override
    public boolean putJSlobStorage(final JSlobStorage jslobStorage) {
        return (null == registry.putIfAbsent(jslobStorage.getIdentifier(), jslobStorage));
    }

    @Override
    public void removeJSlobStorage(final String storageId) throws OXException {
        registry.remove(storageId);
    }

}

==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.jslob/src/com/openexchange/jslob/internal/JSlobStorageRegistryImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.jslob.internal;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import com.openexchange.exception.OXException;
import com.openexchange.jslob.storage.JSlobStorage;
import com.openexchange.jslob.storage.registry.JSlobStorageRegistry;

/**
 * {@link JSlobStorageRegistryImpl}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class JSlobStorageRegistryImpl implements JSlobStorageRegistry {

    private static final JSlobStorageRegistryImpl INSTANCE = new JSlobStorageRegistryImpl();

    /**
     * Gets the instance.
     *
     * @return The instance
     */
    public static JSlobStorageRegistryImpl getInstance() {
        return INSTANCE;
    }

    private final ConcurrentMap<String, JSlobStorage> registry;

    /**
     * Initializes a new {@link JSlobStorageRegistryImpl}.
     */
    private JSlobStorageRegistryImpl() {
        super();
        registry = new ConcurrentHashMap<String, JSlobStorage>(2, 0.9f, 1);
    }

    @Override
    public JSlobStorage getJSlobStorage(final String storageId) throws OXException {
        return registry.get(storageId);
    }

    @Override
    public Collection<JSlobStorage> getJSlobStorages() throws OXException {
        final List<JSlobStorage> list = new ArrayList<JSlobStorage>(8);
        list.addAll(registry.values());
        return list;
    }

    @Override
    public boolean putJSlobStorage(final JSlobStorage jslobStorage) {
        return (null == registry.putIfAbsent(jslobStorage.getIdentifier(), jslobStorage));
    }

    @Override
    public void removeJSlobStorage(final String storageId) throws OXException {
        registry.remove(storageId);
    }

}
